@@ -1,11 +1,4 @@
 import os
-import psycopg2
-
-from functools import partial
-from multiprocessing.pool import ThreadPool
-
-from .utils import roundrobin, run
-
 
 def get_nodes_pg_dump_statements(coordinator):
     configuration = coordinator.configuration
@@ -23,7 +16,7 @@ def get_nodes_pg_dump_statements(coordinator):
 
 def get_rename_node_shards_statements(node, configuration, old=True):
     statements = []
-    statement_first = []
+
     for shard in node.shards:
         if not shard.old_shard:
             continue
@@ -38,19 +31,14 @@ def get_rename_node_shards_statements(node, configuration, old=True):
                 shard.table.name, shard.id,
                 shard.table.name, shard.id))
         else:
-            statement_first.append('ALTER TABLE %s_%d RENAME TO %s_%d_new;\n' % (
-                shard.old_shard.table.name,
-                shard.old_shard.id,
-                shard.old_shard.table.name,
-                shard.old_shard.id))
-            statements.append('ALTER TABLE %s_%d_new RENAME TO %s_%d;\n' % (
+            statements.append('ALTER TABLE %s_%d RENAME TO %s_%d;\n' % (
                 shard.old_shard.table.name,
                 shard.old_shard.id,
                 shard.table.name,
                 shard.id))
             statements.append('DROP TABLE %s_%d_old CASCADE;\n' % (shard.table.name, shard.id))
 
-    return statement_first + statements
+    return statements
 
 
 def get_reinit_node_shards_statements(node, configuration):
@@ -82,23 +70,14 @@ def dump_rename_node_shards_to_old_file(coordinator, configuration):
 
 
 def rename_node_shards(coordinator, configuration, old=True):
-    command = 'psql %s -f %s -q'
+    command = 'psql "%s"  -a -f %s'
 
-    statements = []
     for node in coordinator.nodes:
         if old:
             file_path = os.path.join(configuration.dump_folder, '%s_rename_shard_old.sql' % node.name)
         else:
             file_path = os.path.join(configuration.dump_folder, '%s_rename_shard_new.sql' % node.name)
-
-        statements.append(command % (node.connection_string, file_path))
-
-    pool = ThreadPool(configuration.parallel_tasks)
-    for cmd, rc in pool.imap_unordered(run, statements):
-        print('{cmd} return code: {rc}'.format(**vars()))
-
-    pool.close()
-    pool.join()
+        os.system(command % (node.connection_string, file_path))
 
 
 def dump_rename_node_shards_to_new_file(coordinator,  configuration):
@@ -110,11 +89,9 @@ def dump_rename_node_shards_to_new_file(coordinator,  configuration):
 
 
 def get_nodes_pg_restore_statements(coordinator):
-
     command = "%(pg_restore)s --no-acl --no-owner -j %(jobs)d -d '%(host)s' %(path)s --disable-triggers"
 
-    commands_schema = []
-    commands_data = []
+    commands = []
 
     for node in coordinator.nodes:
         if (coordinator.configuration.restore_nodes_data
@@ -133,13 +110,11 @@ def get_nodes_pg_restore_statements(coordinator):
                 future_shards[shard.future_shard.node] += ' -t %s_%d' % (shard.table.name, shard.id)
 
         for new_node, shards in future_shards.items():
-            base_command = command % {
+            commands.append(command % {
                 'pg_restore': coordinator.configuration.pg_restore,
                 'host': new_node.connection_string,
                 'path': node.dump_file,
                 'jobs': coordinator.configuration.dump_jobs
-            } + shards
-            commands_schema.append(base_command + ' --schema-only')
-            commands_data.append(base_command + ' --data-only')
+            } + shards)
 
-    return commands_schema, commands_data
+    return commands
